Crate equt_md_html

Crate equt_md_html 

Functions

push_html
Iterate over an Iterator of Events, generate HTML for each Event, and push it to a String.
write_html
Iterate over an Iterator of Events, generate HTML for each Event, and write it out to a writable stream.